#
# spec file for package afterburn
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags -Clink-arg=-Wl,-z,relro,-z,now

%global dracutmodulesdir %(pkg-config --variable=dracutmodulesdir dracut || echo '/usr/lib/dracut/modules.d')

Name:           afterburn
Version:        5.3.0
Release:        bp155.1.16
Summary:        A cloud provider agent
License:        Apache-2.0
URL:            https://coreos.github.io/afterburn/
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Patch1:         fix-authorized-keys-location.patch
Patch2:         set-default-user.patch
Patch3:         no-network-args.patch

ExcludeArch:    %ix86 s390x ppc64le

BuildRequires:  cargo
BuildRequires:  rust >= 1.56.0
BuildRequires:  pkgconfig(openssl)

%description
Afterburn is a one-shot agent for cloud-like platforms which interacts with provider-specific metadata endpoints.

%package dracut
Summary:        Dracut modules for afterburn
BuildRequires:  pkgconfig(dracut)
Requires:       %{name}%{?_isa} = %{?epoch:}%{version}-%{release}
Requires:       dracut

%description dracut
Dracut module that enables afterburn and corresponding services
to run in the initramfs on boot.

%prep
%autosetup -N -a1
%patch1 -p1
%patch2 -p0
%patch3 -p0

mkdir .cargo
cp %{SOURCE2} .cargo/config
# Remove exec bits to prevent an issue in fedora shebang checking
find vendor -type f -name \*.rs -exec chmod -x '{}' +

%build
export RUSTFLAGS="%{rustflags}"
cargo build --offline --release

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -D -d -m 0755 %{buildroot}%{_unitdir}
install -D -d -m 0755 %{buildroot}%{_sysconfdir}/cmdline.d

install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -m 0644 %{_builddir}/%{name}-%{version}/systemd/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -m 0644 %{_builddir}/%{name}-%{version}/systemd/%{name}-checkin.service %{buildroot}%{_unitdir}/%{name}-checkin.service
install -m 0644 %{_builddir}/%{name}-%{version}/systemd/%{name}-firstboot-checkin.service %{buildroot}%{_unitdir}/%{name}-firstboot-checkin.service
install -m 0644 %{_builddir}/%{name}-%{version}/systemd/%{name}-sshkeys.target %{buildroot}%{_unitdir}/%{name}-sshkeys.target
sed -e 's,@DEFAULT_INSTANCE@,'suse',' < systemd/%{name}-sshkeys@.service.in > systemd/%{name}-sshkeys@.service.tmp
mv systemd/%{name}-sshkeys@.service.tmp systemd/%{name}-sshkeys@.service
install -m 0644 %{_builddir}/%{name}-%{version}/systemd/%{name}-sshkeys@.service %{buildroot}%{_unitdir}/%{name}-sshkeys@.service
mkdir -p %{buildroot}%{dracutmodulesdir}
cp -a dracut/* %{buildroot}%{dracutmodulesdir}
rm %{buildroot}%{dracutmodulesdir}/30afterburn/afterburn-network-kargs.service

%pre
%service_add_pre %{name}.service %{name}-checkin.service %{name}-firstboot-checkin.service %{name}-sshkeys@.service

%post
%service_add_post %{name}.service %{name}-checkin.service %{name}-firstboot-checkin.service %{name}-sshkeys@.service

%preun
%service_del_preun %{name}.service %{name}-checkin.service %{name}-firstboot-checkin.service %{name}-sshkeys@.service

%postun
%service_del_postun %{name}.service %{name}-checkin.service %{name}-firstboot-checkin.service %{name}-sshkeys@.service

%files
%license LICENSE
%doc README.md
%{_bindir}/afterburn
%{_unitdir}/afterburn.service
%{_unitdir}/afterburn-checkin.service
%{_unitdir}/afterburn-firstboot-checkin.service
%{_unitdir}/afterburn-sshkeys@.service
%{_unitdir}/%{name}-sshkeys.target

%files dracut
%dir %{_sysconfdir}/cmdline.d
%{dracutmodulesdir}/30afterburn/

%changelog
* Mon May 23 2022 jan.suse@zerebecki.de
- Update to version 5.3.0:
  * cargo: Afterburn release 5.3.0
  * build(deps): bump nix from 0.24.0 to 0.24.1
  * build(deps): bump anyhow from 1.0.56 to 1.0.57
  * build(deps): bump nix from 0.23.1 to 0.24.0
  * systemd: enable sshkeys on Power VS platform
  * network: Encode information for systemd-networkd-wait-online
  * build(deps): bump ipnetwork from 0.18.0 to 0.19.0
  * build(deps): bump crossbeam-channel from 0.5.2 to 0.5.4
  * cargo: update to clap 3.1
  * cargo: enable clap wrap_help feature
  * cli: run clap tests
  * cli: avoid deprecated clap constructs
  * cargo: update to clap 3.0
  * cli: use clap mechanism to require exp subcommand
  * build(deps): bump pnet_datalink from 0.28.0 to 0.29.0
  * build(deps): bump pnet_base from 0.28.0 to 0.29.0
  * build(deps): bump slog-term from 2.8.1 to 2.9.0
  * cargo: declare MSRV in Cargo.toml
  * cargo: update to Rust 2021; bump MSRV to 1.56.0
  * workflows: update clippy to 1.59.0
  * copr: abort if specfile fetch fails
  * providers/aws: add AWS_IPV6 attribute
  * providers/aws: bump metadata version to 2021-01-03
  * kubevirt: Add KubeVirt platform support
  * *.service: add/update Documentation field
  * build(deps): bump regex from 1.5.4 to 1.5.5
    fixes RUSTSEC-2022-0013 AKA CVE-2022-24713
  * build(deps): bump reqwest from 0.11.9 to 0.11.10
  * github/release-checklist: Remove Windows binaries from vendored sources
  * build(deps): bump anyhow from 1.0.55 to 1.0.56
  * build(deps): bump mockito from 0.30.0 to 0.31.0
    fixes RUSTSEC-2020-0095
  * aws/mock_tests: explicitly drop mocks before resetting
  * aws/mock_tests: split out IMDS tests
  * aws/mock_tests: factor out map building
  * build(deps): bump anyhow from 1.0.54 to 1.0.55
  * workflows/rpm: reword workflow and job name
  * workflows/rpm: do full git clone
  * build(deps): bump anyhow from 1.0.53 to 1.0.54
  * workflows: add "RPM build" test
  * templates/release-checklist: add Fedora/RHCOS packaging instructions
  * lockfile: refresh
  * tests: explicitly scope conflicting mocks
  * Add COPR integration Makefile
  * build(deps): bump serde_json from 1.0.78 to 1.0.79
  * build(deps): bump crossbeam-utils from 0.8.5 to 0.8.7
  * build(deps): bump block-buffer from 0.10.0 to 0.10.2
  * build(deps): bump thread_local from 1.1.3 to 1.1.4
    fixes RUSTSEC-2022-0006
  * build(deps): bump slog-term from 2.8.0 to 2.8.1
  * build(deps): bump serde from 1.0.135 to 1.0.136
  * *: use `RemainAfterExit` on all oneshot services
  * build(deps): bump anyhow from 1.0.52 to 1.0.53
  * build(deps): bump serde_json from 1.0.75 to 1.0.78
  * build(deps): bump mailparse from 0.13.7 to 0.13.8
  * build(deps): bump serde from 1.0.134 to 1.0.135
  * ci: skip broken kdump.crash kola test Issue: https://github.com/coreos/fedora-coreos-tracker/issues/1075
  * build(deps): bump serde from 1.0.133 to 1.0.134
  * build(deps): bump serde_json from 1.0.74 to 1.0.75
* Tue Jan 18 2022 jan.suse@zerebecki.de
- Update to version 5.2.0:
  * providers: log message when SSH key is removed
  * providers: limit hostname file output value to HOST_NAME_MAX bytes
  * Consistently un-capitalize log messages
  * Explicitly log the hostname we write
  * providers/microsoft: allow unused fields in goal state structs
  * providers: only log we wrote SSH keys when we actually did
- Update to version 5.1.0:
  * Add PowerVS provider
  * cli: correctly print version when --version specified
  * cli: don't report an error when --help or --version is specified
  * providers/packet: access metadata service over HTTPS
  * providers/gcp: access GCP metadata service by IP address
  * minimum supported rust version is now 1.49.0
  * Refresh fix-authorized-keys-location.patch
* Thu Jan 13 2022 jan.suse@zerebecki.de
- Update some dependencies
  * build(deps): bump nix from 0.17.0 and 0.20.0 to 0.23.1
    This fixes the following security issues:
    https://rustsec.org/advisories/RUSTSEC-2021-0119
  * build(deps): bump generic-array from 0.12.3 to 0.12.4
    This fixes a security issue:
    https://rustsec.org/advisories/RUSTSEC-2020-0146 AKA CVE-2020-36465
  * build(deps): bump futures-util from 0.3.6 to 0.3.15
    This fixes a security issue:
    https://rustsec.org/advisories/RUSTSEC-2020-0059 AKA CVE-2020-35905
  * build(deps): bump rand_core from 0.6.1 to 0.6.3
    This fixes a security issue:
    https://rustsec.org/advisories/RUSTSEC-2021-0023
    AKA CVE-2021-27378, bsc#1182432
  * build(deps): bump hyper from 0.14.2 to 0.14.11
    This fixes two security issues:
    https://rustsec.org/advisories/RUSTSEC-2021-0078
    AKA CVE-2021-32715, bsc#1188173
    https://rustsec.org/advisories/RUSTSEC-2021-0079
    AKA CVE-2021-32714, bsc#1188174
  * build(deps): bump tokio from 1.0.1 to 1.15.0
    This fixes two security issues:
    https://rustsec.org/advisories/RUSTSEC-2021-0124
    AKA CVE-2021-45710, bsc#1194119
    https://rustsec.org/advisories/RUSTSEC-2021-0072 AKA CVE-2021-38191
- Remove cargo_audit service, as it makes no sense as a service (it doesn't
  automatically get rerun), it would make more sense during the build process
  as then it gets rerun if the package or the vulnerability database get
  changed
- switch services from disabled to manual
- remove hard coded author for tar_scm service
* Tue Nov 16 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- No reason to exclude armv7, since it builds properly
* Tue Nov  2 2021 William Brown <william.brown@suse.com>
- Add cargo_audit service
- Resolve incomplete use of services for getting source tars.
* Tue Nov  2 2021 slunkad@suse.de
- Update to version 5.0.0:
  * cargo: Afterburn release 5.0.0
  * providers: add Azure Stack Hub (azurestack)
  * providers: move azure into microsoft module
  * build(deps): bump anyhow from 1.0.39 to 1.0.40
  * ci: adapt to new buildroot image
  * build(deps): bump serde from 1.0.124 to 1.0.125
  * build(deps): bump anyhow from 1.0.38 to 1.0.39
  * cargo: accept mockito 0.29
  * build(deps): bump mockito from 0.29.0 to 0.30.0
  * cli: stop wrapping command-line parse errors
  * Switch from error-chain to anyhow
* Tue Jul 13 2021 Robert Schweikert <rjschwei@suse.com>
- Forward port fix-authorized-keys-location.patch
* Mon Jul 12 2021 Robert Schweikert <rjschwei@suse.com>
- Add set-default-user.patch
  + Set the default user to suse
- Add fix-authorized-keys-location.patch
  + Write the ssh keys to the standard location
- Add no-network-args.patch
  + Networks arguments on the kernel command line are set during image build
    there is no need for another place for a hard coded list.
- Create target dir for afterburn to write configuration file to
* Fri Jun 11 2021 Sayali Lunkad <sayali.lunkad@suse.com>
- Add dracut modules for afterburn
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.0.0
  * Update minimum rust toolchain version 1.44
  * Switch from error-chain to anyhow
  * Remove cl-legacy feature
  * ibmcloud: don't ignore I/O error when parsing metadata
  * providers: fix clippy::unnecessary_wraps lint on 1.50
  * workflows: update pinned lint toolchain to 1.50.0
  * cli: stop wrapping command-line parse errors
  * github: release checklist cleanups
  * providers: add Azure Stack Hub
* Fri Mar 19 2021 Sayali Lunkad <sayali.lunkad@suse.com>
- Set rust version to minimum required by upstream
* Tue Mar 16 2021 Jan Engelhardt <jengelh@inai.de>
- Reduce boilerplate emission from %%service_*. Add a bit of build
  recipe modernization and safeguarding.
* Tue Mar 16 2021 Sayali Lunkad <sayali.lunkad@suse.com>
- Initial commit
